@@ -19,7 +19,8 @@
 
 #include "akonadistarter.h"
 
-#include "../../libs/protocol_p.h"
+#include <akapplication.h>
+#include <akdbus.h>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
@@ -32,18 +33,23 @@ AkonadiStarter::AkonadiStarter(QObject * parent) :
     QObject( parent ),
     mRegistered( false )
 {
-  QDBusServiceWatcher *watcher = new QDBusServiceWatcher( QLatin1String( AKONADI_DBUS_CONTROL_SERVICE_LOCK ),
+  QDBusServiceWatcher *watcher = new QDBusServiceWatcher( AkDBus::serviceName(AkDBus::ControlLock),
                                                           QDBusConnection::sessionBus(),
                                                           QDBusServiceWatcher::WatchForOwnerChange, this );
 
-  connect( watcher, SIGNAL( serviceOwnerChanged( const QString&, const QString&, const QString& ) ),
-           this, SLOT( serviceOwnerChanged( const QString&, const QString&, const QString& ) ) );
+  connect( watcher, SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+           this, SLOT(serviceOwnerChanged(QString,QString,QString)) );
 }
 
 bool AkonadiStarter::start()
 {
   qDebug( "Starting Akonadi Server..." );
-  const bool ok = QProcess::startDetached( QLatin1String("akonadi_control") );
+
+  QStringList serverArgs;
+  if ( !AkApplication::instanceIdentifier().isEmpty() )
+    serverArgs << QLatin1String("--instance") << AkApplication::instanceIdentifier();
+  
+  const bool ok = QProcess::startDetached( QLatin1String("akonadi_control"), serverArgs );
   if ( !ok ) {
     qDebug( "Error: unable to execute binary akonadi_control" );
     return false;
@@ -56,7 +62,7 @@ bool AkonadiStarter::start()
 
   if ( !mRegistered ) {
     qDebug( "Error: akonadi_control was started but didn't register at D-Bus session bus." );
-    qDebug( "Make sure your system is setup correctly!" );
+    qDebug( "Make sure your system is set up correctly!" );
     return false;
   }
 
